@@ -2,10 +2,9 @@
 #if 0 // def Q_OS_SYMBIAN
 #warning "Working around broken external symbian string macros!!"
 #define APPNAME "cacheme"
-#define VERSION "0.8"
+#define VERSION "0.8.4"
 #define DATADIR "/data/cacheme"
 #define LIBDIR "/data/cacheme"
-#define EXPIRATION_DATE "01082011"
 #endif
 
 class Config {
@@ -25,6 +24,8 @@ class Config {
   static const int MAP_WIDGET_ICON_SIZE = 48;
   static const int MAP_BANNER_FONT_SIZE = 24;
 #endif
+  static const int MAP_BUTTON_MAX_SIZE_HIREZ = 1.5*MAP_BUTTON_MAX_SIZE;
+  static const int MAP_WIDGET_ICON_SIZE_HIREZ = 1.5*MAP_WIDGET_ICON_SIZE;
   static const int MAP_BUBBLE_BIG_SIZE = 4*MAP_BUBBLE_BASE_SIZE/3;
   static const int MAP_BANNER_BORDER = MAP_BANNER_FONT_SIZE/4;
 };
