@@ -2,11 +2,15 @@
 
 #include "mapwidget.h"
 #include "mapbuttonmanager.h"
-#include "size.h"
+#include "config.h"
 
-MapButtonManager::MapButtonManager(MapWidget *mapWidget) : QList<MapButton*>() {
+MapButtonManager::MapButtonManager(MapWidget *mapWidget) : QList<MapButton*>(), m_iconLoader(NULL) {
   this->m_mapWidget = mapWidget;
-  this->m_iconLoader = new IconLoader(Size::MAP_BUTTON_MAX_SIZE);
+
+  if(this->m_mapWidget->hiRez())
+    this->m_iconLoader = new IconLoader(Config::MAP_BUTTON_MAX_SIZE_HIREZ);
+  else
+    this->m_iconLoader = new IconLoader(Config::MAP_BUTTON_MAX_SIZE);
 }
 
 MapButtonManager::~MapButtonManager() {
@@ -44,7 +48,10 @@ void MapButtonManager::paint(QPainter *painter) {
 
   // check of buttons size is still appropriate for screen
   // three buttons need 3*size + 4 * border (==size/4) = 4*size
-  int bsize = Size::MAP_BUTTON_MAX_SIZE;
+  int bsize = Config::MAP_BUTTON_MAX_SIZE;
+  if(this->m_mapWidget->hiRez())
+    bsize = Config::MAP_BUTTON_MAX_SIZE_HIREZ;
+
   if(bsize > m_mapWidget->size().height()/4)
     bsize = m_mapWidget->size().height()/4;
 
