@@ -14,11 +14,13 @@ void SettingsDialog::applyChanges() {
 
   int type = m_typeCombo->itemData(m_typeCombo->currentIndex()).toInt();
   QString serviceStr = m_serviceCombo->currentText();
+  bool hiRez = m_hiRez->isChecked();
 
   QSettings settings;
   settings.beginGroup("Map");
   settings.setValue("Type", type);
   settings.setValue("Service", serviceStr);
+  settings.setValue("HiRez", hiRez);
   settings.endGroup();
 
   settings.beginGroup("Account");
@@ -26,8 +28,9 @@ void SettingsDialog::applyChanges() {
   settings.setValue("Password", m_password->text());
   settings.endGroup();
 
-  // type is handled immediately
+  // type and hirez is handled immediately
   m_mapWidget->setMapType((QGraphicsGeoMap::MapType)type);
+  m_mapWidget->setHiRez(hiRez);
 }
 
 SettingsDialog::SettingsDialog(MapWidget *mapWidget, 
@@ -38,26 +41,33 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
 
   setWindowTitle(tr("Settings"));
 
-  QVBoxLayout *mainLayout = new QVBoxLayout;
-  mainLayout->setContentsMargins(0,0,0,0);
+#ifdef Q_WS_MAEMO_5
+  resize(QSize(800, 800));
+
+  QVBoxLayout *outerLayout = new QVBoxLayout;
 
   QScrollArea *scrollArea = new QScrollArea(this);
   scrollArea->setWidgetResizable(true);
   scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
   QWidget *scrollWidget = new QWidget;
-  QVBoxLayout *scrollvbox = new QVBoxLayout;
-  scrollvbox->setContentsMargins(0,0,0,0);
+  QVBoxLayout *mainLayout = new QVBoxLayout;
+  mainLayout->setContentsMargins(0,0,0,0);
+#else
+  QVBoxLayout *mainLayout = new QVBoxLayout;
+#endif
 
-  QGroupBox *groupBox = new QGroupBox(tr("Map"));
-  QVBoxLayout *vbox = new QVBoxLayout;
+  QGroupBox *groupBox = new QGroupBox();
+  QGridLayout *grid = new QGridLayout;
+  grid->setContentsMargins(0,0,0,0);
+  grid->setVerticalSpacing(0);
 
   const QString mapTypeStr[] = {
     "No Map", tr("Street Map"), tr("Satellite Map Day"), 
     tr("Satellite Map Night"), tr("Terrain Map") };
 
   /* -------------- map type combo box --------------- */
-  vbox->addWidget(new QLabel(tr("Map type") + ":", this));
+  grid->addWidget(new QLabel(tr("Map type") + ":", this), 0, 0);
 
   m_typeCombo = new QComboBox(this);
   QList<QGraphicsGeoMap::MapType> types = mapWidget->supportedMapTypes(); 
@@ -70,10 +80,10 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
       m_typeCombo->setCurrentIndex(i);
   }
 
-  vbox->addWidget(m_typeCombo);
+  grid->addWidget(m_typeCombo, 0, 1);
 
   /* -------------- geo service combo box --------------- */
-  vbox->addWidget(new QLabel(tr("Map service") + ":", this));
+  grid->addWidget(new QLabel(tr("Map service") + ":", this), 1, 0);
 
   m_serviceCombo = new QComboBox(this);
   QStringList list = QGeoServiceProvider::availableServiceProviders();
@@ -84,14 +94,20 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
       m_serviceCombo->setCurrentIndex(i);
   }
  
-  vbox->addWidget(m_serviceCombo);
-  QLabel *label = new QLabel(tr("A change of the map service "
-				"takes effect after restart."), this);
+  grid->addWidget(m_serviceCombo, 1, 1);
+  QLabel *label = new QLabel("<small>" + tr("A change of the map service "
+			"takes effect after restart.") + "</small>", this);
   label->setWordWrap(true);
-  vbox->addWidget(label);
+  grid->addWidget(label, 2, 0, 1, 2);
+
+  groupBox->setLayout(grid);
+  mainLayout->addWidget(groupBox);
+
+  /* -------------- hirez switch ------------------ */
+  m_hiRez = new QCheckBox( tr("High density display"), this);
+  m_hiRez->setChecked(mapWidget->hiRez());
+  mainLayout->addWidget(m_hiRez);
 
-  groupBox->setLayout(vbox);
-  scrollvbox->addWidget(groupBox);
 
   /* ------------------- user configuration --------------------- */
 
@@ -99,22 +115,25 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
   settings.beginGroup("Account");
 
   groupBox = new QGroupBox(tr("Geocaching.com account"));
-  vbox = new QVBoxLayout;
+  grid = new QGridLayout;
+  grid->setContentsMargins(0,0,0,0);
+  grid->setVerticalSpacing(0);
 
   /* -------------- user name entry --------------- */
 
-  vbox->addWidget(new QLabel(tr("Username") + ":"));
+  grid->addWidget(new QLabel(tr("Username") + ":"), 0, 0);
   m_name = new QLineEdit(settings.value("Name", "").toString());
-  vbox->addWidget(m_name);
+  grid->addWidget(m_name, 0, 1);
 
   /* -------------- password entry --------------- */
-  vbox->addWidget(new QLabel(tr("Password") + ":"));
+  grid->addWidget(new QLabel(tr("Password") + ":"), 1, 0);
   m_password = new QLineEdit(settings.value("Password", "").toString());
   m_password->setEchoMode(QLineEdit::PasswordEchoOnEdit);
-  vbox->addWidget(m_password);
+  grid->addWidget(m_password, 1, 1);
+
+  groupBox->setLayout(grid);
+  mainLayout->addWidget(groupBox);
 
-  groupBox->setLayout(vbox);
-  scrollvbox->addWidget(groupBox);
 
   settings.endGroup();
 
@@ -122,12 +141,9 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
 
   /* ------------------------ plugins ------------------------ */
 
-  cacheProvider->pluginConfig(this, scrollvbox);
-
-  scrollvbox->addStretch();
-  scrollWidget->setLayout(scrollvbox);
-  scrollArea->setWidget(scrollWidget);
-  mainLayout->addWidget(scrollArea);
+  // currently all plugins just connect to the accept signal, but
+  // don't create any own settings
+  cacheProvider->pluginConfig(this, mainLayout);
 
   QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
 				     | QDialogButtonBox::Cancel);
@@ -135,7 +151,16 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
   connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
   connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
+#ifdef Q_WS_MAEMO_5
+  mainLayout->addStretch();
+  scrollWidget->setLayout(mainLayout);
+  scrollArea->setWidget(scrollWidget);
+  outerLayout->addWidget(scrollArea);
+
+  outerLayout->addWidget(buttonBox);
+  setLayout(outerLayout);
+#else
   mainLayout->addWidget(buttonBox);
   setLayout(mainLayout);
-
+#endif
 }
